#!/bin/bash
#This shell script will help you to install the alsa driver
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:~/bin
export PATH

KERNEL_VER=`uname -r`
DRIVER_VER=1.0.18rc3
LIB_VER=1.0.18rc3
UTILS_VER=1.0.16

function rmfolder() {
rm -rf alsa-driver-$DRIVER_VER > /dev/null
rm -rf alsa-lib-$LIB_VER > /dev/null
rm -rf alsa-utils-$UTILS_VER > /dev/null
}

echo "Checking old driver..."
lsmod | grep 'snd_hda_intel' >/dev/null
if [ $? -eq 0 ]
then echo "You have already install the driver."
echo "Continue?"
select i in "OK,exiting." "Still continue..."
do case $i in
"OK,exiting.") exit 0
;;
"Still continue...") echo "OK,continuing..." 
break
;;
esac
done
fi

echo "I'll help you to install the alsa driver now."
echo 
sleep 1

#Check if user are using root account
echo "First, check if you are using root account."
if [ $UID -ne 0 ]
then echo "Please login as root." && exit 1
else echo "OK,go on."
fi
sleep 2

#Check if user have installed the kernel source
echo "Second, please make sure you have installed the kernel source."
if [ -L /lib/modules/$KERNEL_VER/source -a -L /lib/modules/$KERNEL_VER/build ]
  then echo "It's OK."
else echo "You haven't installed the kernel source." && exit 1
fi
sleep 2

#Check if user have installed make and gcc packages
echo "Third, please make sure \
you have installed make and gcc packages."
make --version >/dev/null
if [ $? -ne 0 ]
then echo "You haven't installed make packages."
echo "Installing failed."  && exit 1 
fi
gcc --version >/dev/null
if [ $? -ne 0 ]
then echo "You haven't intalled gcc packages."
echo "Installing failed." && exit 1
fi
echo "OK, continuing."

#Decompress the driver source
echo "Then, I'll installed the driver for you."
echo "Deompress the driver source"
tar jxvf alsa-driver-$DRIVER_VER.tar.bz2 > /dev/null
tar jxvf alsa-lib-$LIB_VER.tar.bz2 > /dev/null
tar jxvf alsa-utils-$UTILS_VER.tar.bz2 > /dev/null
sync
sleep 2

## remove driver modules
if [ -f /etc/rc.d/init.d/alsasound ]; then
   /etc/init.d/alsasound stop 2> /dev/null
   rmmod snd-page-alloc > /dev/null 2>&1 
   rmmod soundcore > /dev/null 2>&1
fi

sleep 2

echo "Compile Driver........"
cd alsa-driver-$DRIVER_VER
./configure --with-cards=hda-intel
if [ $? -ne 0 ]
then echo "configure failed, please check about your settings!" ;
rmfolder ;
exit 1 ;
fi
make
make install
if [ $? -ne 0 ]
then echo "Alsa driver compiling failed!" ;
rmfolder ;
exit 1 ;
fi
./snddevices
cd ..

## for x86
echo "Remove old alsa library"
rm -rf /lib/libasound.* > /dev/null 2>&1 
rm -rf /lib64/libasound.* > /dev/null 2>&1 
rm -rf /usr/lib/libasound.* > /dev/null 2>&1 
rm -rf /usr/lib64/libasound.* > /dev/null 2>&1

echo "Compile ALSA Library....."
cd alsa-lib-$LIB_VER
./configure
make
make install
if [ $? -ne 0 ]
then echo "Alsa Libarary compiling failed!" ;
rmfolder ;
exit 1
fi
cd ..


echo "Compile ALSA Utility......"
cd alsa-utils-$UTILS_VER
./configure
make
make install
if [ $? -ne 0 ]
  then echo "Alsa utility compiling failed!" 
rmfolder
exit 1
fi
cd ..

## for x86_64
if [ -d /usr/lib64 ]; then
  cp -lf /usr/lib/libasound.* /usr/lib64
  cp -lf /usr/lib/pkgconfig/alsa.pc /usr/lib64/pkgconfig
  ldconfig -n /usr/lib64
fi

sleep 1

## del audio stat file
if [ -f /etc/asound.state ]; then
   rm -rf /etc/asound.state > /dev/null 2>&1
fi

## alsa driver sndstat file relink
rm -rf /dev/sndstat > /dev/null 2>&1
ln -s /proc/asound/oss/sndstat /dev/sndstat


echo "Remove Folder....."
rmfolder

echo "Configure the alsa driver....."
alsaconf

echo "May I restart your computer to load new driver?"
select i in "Restart..." "Exit the script."
do case $i in
"Restart...") shutdown -r now
;;
"Exit the script.") echo "exiting..." && exit 0
;;
esac
done
